@@ -218,7 +218,7 @@ class CGGoogleMaps extends CGExtensions
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '2.1';
+    return '2.1.3';
   }
 
 
