@@ -11,6 +11,7 @@ $lang['anchor_y'] = 'Anker Y pixel lokasjon';
 $lang['apply'] = 'Utf&oslash;r';
 $lang['ask_delete_icon'] = 'Er du sikker p&aring; at vil fjerne dette ikonet fra listen (ingen filer vil bli slettet)';
 $lang['ask_reset_icons'] = 'Er du sikker p&aring; at du vil fjerne alle ikoner, og tilbakestille til fabrikkstandard?';
+$lang['baloon_maptemplate'] = 'Boble mal';
 $lang['cancel'] = 'Avbryt';
 $lang['category_template'] = 'Kategori visningsmal';
 $lang['center_lat'] = 'Sentrer Breddegrad(Latitude)';
@@ -90,7 +91,9 @@ $lang['help'] = '<h3>What does this do</h3>
 <p>You can use smarty to add points to a module dynamically.  You can use this functionality to build a frappr like map with multiple points that are controlled dynamically from another module (like CompanyDirectory or FrontEndUsers).</p>
 <h4>The {cggm_add_dynpoint} Smarty Plugin</h4>
 <p>This smarty plugin <em>(only available when CGGoogleMaps is installed)</em> allows adding a point dynamically to a specified map.</p>
-<h5>Parameters:<h5>
+<h4>Usage:</h4>
+<pre><code>{cggm_add_dynpoint map=1 name=&#039;New York&#039; address=&#039;New York, NY&#039; icon=&#039;food&#039;}</code></pre><br/>
+<h4>Parameters:</h4>
   <ul> 
 <li><strong>required</strong> - map : The (integer) ID of the map to add the point to</li>
 <li><strong>required</strong> - name : The name of the point to add</li>
@@ -118,6 +121,8 @@ module homepage at <a href="http://calguy1000.com">calguy1000.com</a>.</li>
 <li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
 <li>Lastly, you may have some success emailing the author directly.</li>  
 </ul>
+<h3>Requirements</h3>
+<p>This map functionality makes extensive use of <strong>JQuery</strong> it is your responsibility to include jquery in pages that use these maps and ensure that it is loaded before the map is called.  The easiest way to do this is by installing the JQueryTools module and adding {JQueryTools action=incjs} into the head portion of your page template.</p>
 <h3>Copyright and License</h3>
 <p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
 <p>This program is free software; you can redistribute it and/or modify
@@ -178,6 +183,8 @@ $lang['info_scalecontrols'] = 'En skalerer kan valgfritt vises i nedre h&oslash;
 $lang['info_sensor'] = 'Noen nettlesere (spesielt mobile nettlesere) er i stand til &aring; gi bredde- og lengdegrad. Vil du aktivere dette?';
 $lang['info_sidebar'] = 'Skal et sidepanel inneholdende alle kartpunkter vises?';
 $lang['info_sv_controls'] = 'Skal Gatevisningskontroller vises p&aring; kartet?';
+$lang['info_sv_radius'] = 'N&aring;r Streetview er p&aring;sl&aring;tt for en mark&oslash;r, hvor langt bort (i meter) skal den s&oslash;ke etter en gyldig streetview plassering.  Dette er viktig i i mer lettbebygde str&oslash;k hvor StreetView ikke n&oslash;dvendigvis har g&aring;tt gjennom hver gate.';
+$lang['info_sysdflt_baloon_template'] = 'Systemstandard &quot;Boble&quot; mal';
 $lang['info_sysdflt_category_template'] = 'Systemstandard &quot;Kategoriliste&quot; mal';
 $lang['info_sysdflt_dirform_template'] = 'Systemstandard &quot;Kj&oslash;reruteskjema&quot; mal';
 $lang['info_sysdflt_js_template'] = 'Systemstandard javascriptmal';
@@ -200,6 +207,7 @@ $lang['longitude'] = 'Lengdegrad(Longitude)';
 $lang['make_default'] = 'gj&oslash;r dette ikonet til standard ikon';
 $lang['marker_categories'] = 'Mark&oslash;r kategorier';
 $lang['marker_icons'] = 'Mark&oslash;rikoner';
+$lang['marker_skipped'] = 'Geografisk plassering (adresse til lat/long) mislyktes .. marker &quot;%s&quot; som hoppet over';
 $lang['map'] = 'Kart';
 $lang['maps'] = 'Kart';
 $lang['maptemplate_addedit'] = 'Legg til/rediger kartmal';
@@ -256,6 +264,7 @@ $lang['sidebar_template'] = 'Sidestolpe mal';
 $lang['small'] = 'Liten';
 $lang['submit'] = 'Utf&oslash;r';
 $lang['sv_controls'] = 'Vis gatevisningskontroller';
+$lang['sv_radius'] = 'Streetview s&oslash;keradius';
 $lang['tab_advanced'] = 'Avansert';
 $lang['tab_directions'] = 'Kj&oslash;rerute';
 $lang['tab_jstemplate'] = 'Javascriptmal';
@@ -272,9 +281,9 @@ $lang['use_marker_icon'] = 'Foretrekk mark&oslash;rikonet';
 $lang['width'] = 'Bredde';
 $lang['window'] = 'Vindu';
 $lang['zoom_encompass'] = 'Zoom tilpasset';
-$lang['utmz'] = '156861353.1288991067.3364.78.utmccn=(referral)|utmcsr=cmsmadesimple.org|utmcct=/about-link/special-fans-listing/|utmcmd=referral';
-$lang['utma'] = '156861353.179052623084110100.1210423577.1290634506.1290638627.3419';
+$lang['utmz'] = '156861353.1292071197.3458.79.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,49989.0/topicseen.html';
+$lang['utma'] = '156861353.179052623084110100.1210423577.1295909416.1295985955.3518';
 $lang['qca'] = '1210971690-27308073-81952832';
+$lang['utmb'] = '156861353.2.10.1295985955';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
