@@ -126,7 +126,7 @@ class cggm_map_generator
 		}
 	    }
 	}
-	if( $marker->get_icon() == '' )
+	if( $marker->get_icon() == '' || $marker->get_icon() == -1 )
 	  {
 	    $marker->set_icon($map->default_icon);
 	  }
@@ -138,7 +138,7 @@ class cggm_map_generator
 	    if( !$coords )
 	      {
 		// this point has to be skipped
-		$this->_errors[] = $mod->Lang('marker_skipped',$marker->name);
+		$this->_errors[] = $mod->Lang('marker_skipped',$marker->get_title());
 		continue;
 	      }
 	    $marker->set_coords($coords[0],$coords[1]);
